@@ -18,6 +18,7 @@ package org.kie.workbench.common.dmn.client.editors.expressions.types.dtable;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
@@ -26,37 +27,44 @@ import java.util.function.Supplier;
 import javax.enterprise.event.Event;
 
 import com.ait.lienzo.shared.core.types.EventPropagationMode;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.HasTypeRef;
 import org.kie.workbench.common.dmn.api.definition.model.BuiltinAggregator;
+import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
 import org.kie.workbench.common.dmn.api.definition.model.DMNModelInstrumentedBase;
 import org.kie.workbench.common.dmn.api.definition.model.DecisionRule;
 import org.kie.workbench.common.dmn.api.definition.model.DecisionTable;
 import org.kie.workbench.common.dmn.api.definition.model.HitPolicy;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.model.InputClause;
 import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.definition.model.OutputClause;
+import org.kie.workbench.common.dmn.api.definition.model.RuleAnnotationClause;
 import org.kie.workbench.common.dmn.api.definition.model.UnaryTests;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.api.property.dmn.QName;
+import org.kie.workbench.common.dmn.api.property.dmn.Text;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.AddDecisionRuleCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.AddInputClauseCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.AddOutputClauseCommand;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.AddRuleAnnotationClauseCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.DeleteDecisionRuleCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.DeleteInputClauseCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.DeleteOutputClauseCommand;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.DeleteRuleAnnotationClauseCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.SetBuiltinAggregatorCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.SetHitPolicyCommand;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
-import org.kie.workbench.common.dmn.client.commands.general.DeleteHasNameCommand;
-import org.kie.workbench.common.dmn.client.commands.general.SetHasNameCommand;
+import org.kie.workbench.common.dmn.client.commands.general.DeleteHasValueCommand;
+import org.kie.workbench.common.dmn.client.commands.general.SetHasValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetTypeRefCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.hitpolicy.HasHitPolicyControl;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.hitpolicy.HitPolicyPopoverView;
 import org.kie.workbench.common.dmn.client.editors.expressions.util.SelectionUtils;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
@@ -82,7 +90,6 @@ import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridRow;
-import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
 import org.uberfire.ext.wires.core.grids.client.util.CellContextUtilities;
 import org.uberfire.mvp.Command;
 
@@ -93,10 +100,8 @@ import static org.uberfire.ext.wires.core.grids.client.util.ColumnIndexUtilities
 public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, DecisionTableGridData, DecisionTableUIModelMapper> implements HasListSelectorControl,
                                                                                                                                        HasHitPolicyControl {
 
-    public static final String DESCRIPTION_GROUP = "DecisionTable$Description";
-
     private final HitPolicyPopoverView.Presenter hitPolicyEditor;
-    private final NameAndDataTypePopoverView.Presenter headerEditor;
+    private final ManagedInstance<ValueAndDataTypePopoverView.Presenter> headerEditors;
 
     private final TextAreaSingletonDOMElementFactory textAreaFactory = getBodyTextAreaFactory();
 
@@ -135,7 +140,7 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                              final boolean isOnlyVisualChangeAllowed,
                              final int nesting,
                              final HitPolicyPopoverView.Presenter hitPolicyEditor,
-                             final NameAndDataTypePopoverView.Presenter headerEditor) {
+                             final ManagedInstance<ValueAndDataTypePopoverView.Presenter> headerEditors) {
         super(parent,
               nodeUUID,
               hasExpression,
@@ -157,7 +162,7 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
               isOnlyVisualChangeAllowed,
               nesting);
         this.hitPolicyEditor = hitPolicyEditor;
-        this.headerEditor = headerEditor;
+        this.headerEditors = headerEditors;
 
         setEventPropagationMode(EventPropagationMode.NO_ANCESTORS);
 
@@ -187,7 +192,6 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                                                                 e::getAggregation,
                                                                 cellEditorControls,
                                                                 hitPolicyEditor,
-                                                                Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EditHitPolicy)),
                                                                 getAndSetInitialWidth(uiColumnIndex++, DecisionTableRowNumberColumn.DEFAULT_WIDTH),
                                                                 this));
             for (int index = 0; index < e.getInput().size(); index++) {
@@ -196,26 +200,47 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
             for (int index = 0; index < e.getOutput().size(); index++) {
                 model.appendColumn(makeOutputClauseColumn(uiColumnIndex++, e.getOutput().get(index)));
             }
-            model.appendColumn(new DescriptionColumn(new BaseHeaderMetaData(translationService.format(DMNEditorConstants.DecisionTableEditor_DescriptionColumnHeader),
-                                                                            DESCRIPTION_GROUP),
-                                                     textAreaFactory,
-                                                     getAndSetInitialWidth(uiColumnIndex, DMNGridColumn.DEFAULT_WIDTH),
-                                                     this));
+            for (int index = 0; index < e.getAnnotations().size(); index++) {
+                model.appendColumn(makeRuleAnnotationClauseColumn(uiColumnIndex++, e.getAnnotations().get(index)));
+            }
         }
 
         getRenderer().setColumnRenderConstraint((isSelectionLayer, gridColumn) -> !isSelectionLayer);
     }
 
+    private RuleAnnotationClauseColumn makeRuleAnnotationClauseColumn(final int index,
+                                                                      final RuleAnnotationClause ruleAnnotationClause) {
+        final RuleAnnotationClauseColumn column = new RuleAnnotationClauseColumn(ruleAnnotationClauseHeaderMetaData(ruleAnnotationClause),
+                                                                                 textAreaFactory,
+                                                                                 getAndSetInitialWidth(index, DMNGridColumn.DEFAULT_WIDTH),
+                                                                                 this);
+        return column;
+    }
+
+    private Supplier<List<GridColumn.HeaderMetaData>> ruleAnnotationClauseHeaderMetaData(final RuleAnnotationClause ruleAnnotationClause) {
+        return () -> {
+            final List<GridColumn.HeaderMetaData> metaData = new ArrayList<>();
+            metaData.add(new RuleAnnotationClauseColumnHeaderMetaData(() -> ruleAnnotationClause.getName().getValue(),
+                                                                      (value) -> ruleAnnotationClause.getName().setValue(value),
+                                                                      getHeaderTextBoxFactory(),
+                                                                      Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EnterAnnotation)),
+                                                                      this::getHeaderItems,
+                                                                      listSelector,
+                                                                      this::onItemSelected));
+            return metaData;
+        };
+    }
+
     private InputClauseColumn makeInputClauseColumn(final int index,
                                                     final InputClause ic) {
-        final InputClauseColumn column = new InputClauseColumn(new InputClauseColumnHeaderMetaData(wrapInputClauseIntoHasName(ic),
+        final InputClauseColumn column = new InputClauseColumn(new InputClauseColumnHeaderMetaData(ic.getInputExpression(),
                                                                                                    ic::getInputExpression,
-                                                                                                   clearDisplayNameConsumer(false),
-                                                                                                   setDisplayNameConsumer(false),
+                                                                                                   clearValueConsumer(false, new Text()),
+                                                                                                   setValueConsumer(false),
                                                                                                    setTypeRefConsumer(),
+                                                                                                   translationService,
                                                                                                    cellEditorControls,
-                                                                                                   headerEditor,
-                                                                                                   Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EditInputClause)),
+                                                                                                   headerEditors.get(),
                                                                                                    listSelector,
                                                                                                    this::getHeaderItems,
                                                                                                    this::onItemSelected),
@@ -225,21 +250,6 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
         return column;
     }
 
-    private HasName wrapInputClauseIntoHasName(final InputClause inputClause) {
-        return new HasName() {
-
-            @Override
-            public Name getName() {
-                return new Name(inputClause.getInputExpression().getText().getValue());
-            }
-
-            @Override
-            public void setName(final Name name) {
-                inputClause.getInputExpression().getText().setValue(name.getValue());
-            }
-        };
-    }
-
     private OutputClauseColumn makeOutputClauseColumn(final int index,
                                                       final OutputClause oc) {
         final OutputClauseColumn column = new OutputClauseColumn(outputClauseHeaderMetaData(oc),
@@ -250,30 +260,31 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
     }
 
     private Supplier<List<GridColumn.HeaderMetaData>> outputClauseHeaderMetaData(final OutputClause oc) {
+        final ValueAndDataTypePopoverView.Presenter headerEditor = headerEditors.get();
         return () -> {
             final List<GridColumn.HeaderMetaData> metaData = new ArrayList<>();
             getExpression().get().ifPresent(dtable -> {
                 if (hasName.isPresent()) {
                     metaData.add(new OutputClauseColumnExpressionNameHeaderMetaData(hasExpression,
                                                                                     hasName,
-                                                                                    clearDisplayNameConsumer(true, oc, dtable),
-                                                                                    setDisplayNameConsumer(true, oc, dtable),
+                                                                                    clearValueConsumer(oc, dtable),
+                                                                                    setValueConsumer(oc, dtable),
                                                                                     setTypeRefConsumer(oc, dtable),
+                                                                                    translationService,
                                                                                     cellEditorControls,
                                                                                     headerEditor,
-                                                                                    Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EditOutputClause)),
                                                                                     listSelector,
                                                                                     this::getHeaderItems,
                                                                                     this::onItemSelected));
                 } else {
                     metaData.add(new OutputClauseColumnHeaderMetaData(wrapOutputClauseIntoHasName(oc),
                                                                       oc,
-                                                                      clearDisplayNameConsumer(false),
-                                                                      setDisplayNameConsumer(false),
+                                                                      clearValueConsumer(false, new Name()),
+                                                                      setValueConsumer(false),
                                                                       setTypeRefConsumer(),
+                                                                      translationService,
                                                                       cellEditorControls,
                                                                       headerEditor,
-                                                                      Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EditOutputClause)),
                                                                       listSelector,
                                                                       this::getHeaderItems,
                                                                       this::onItemSelected));
@@ -281,12 +292,12 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                 if (dtable.getOutput().size() > 1) {
                     metaData.add(new OutputClauseColumnHeaderMetaData(wrapOutputClauseIntoHasName(oc),
                                                                       oc,
-                                                                      clearDisplayNameConsumer(false),
-                                                                      setDisplayNameConsumer(false),
+                                                                      clearValueConsumer(false, new Name()),
+                                                                      setValueConsumer(false),
                                                                       setTypeRefConsumer(),
+                                                                      translationService,
                                                                       cellEditorControls,
                                                                       headerEditor,
-                                                                      Optional.of(translationService.getTranslation(DMNEditorConstants.DecisionTableEditor_EditOutputClause)),
                                                                       listSelector,
                                                                       this::getHeaderItems,
                                                                       this::onItemSelected));
@@ -296,50 +307,43 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
         };
     }
 
-    private Consumer<HasName> clearDisplayNameConsumer(final boolean updateStunnerTitle,
-                                                       final OutputClause oc,
-                                                       final DecisionTable dtable) {
+    private Consumer<HasName> clearValueConsumer(final OutputClause oc,
+                                                 final DecisionTable dtable) {
         if (dtable.getOutput().size() == 1) {
-            return clearDisplayNameOnHasExpressionAndOutputClauseConsumer(updateStunnerTitle, oc);
+            return clearDisplayNameOnHasExpressionAndOutputClauseConsumer(oc);
         }
-        return clearDisplayNameConsumer(updateStunnerTitle);
+        return clearValueConsumer(true, new Name());
     }
 
     @SuppressWarnings("unchecked")
-    private Consumer<HasName> clearDisplayNameOnHasExpressionAndOutputClauseConsumer(final boolean updateStunnerTitle,
-                                                                                     final OutputClause oc) {
-        return (hn) -> {
-            final CompositeCommand.Builder commandBuilder = newHasNameHasNoValueCommand(hn);
-            commandBuilder.addCommand(new DeleteHasNameCommand(wrapOutputClauseIntoHasName(oc),
-                                                               () -> {/*Nothing*/}));
-            if (updateStunnerTitle) {
-                getUpdateStunnerTitleCommand("").ifPresent(commandBuilder::addCommand);
-            }
+    private Consumer<HasName> clearDisplayNameOnHasExpressionAndOutputClauseConsumer(final OutputClause oc) {
+        return (hv) -> {
+            final CompositeCommand.Builder commandBuilder = newHasValueHasNoValueCommand(hv, new Name());
+            commandBuilder.addCommand(new DeleteHasValueCommand<>(wrapOutputClauseIntoHasName(oc),
+                                                                  new Name(),
+                                                                  () -> {/*Nothing*/}));
+            getUpdateStunnerTitleCommand(new Name()).ifPresent(commandBuilder::addCommand);
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           commandBuilder.build());
         };
     }
 
-    private BiConsumer<HasName, Name> setDisplayNameConsumer(final boolean updateStunnerTitle,
-                                                             final OutputClause oc,
-                                                             final DecisionTable dtable) {
+    private BiConsumer<HasName, Name> setValueConsumer(final OutputClause oc,
+                                                       final DecisionTable dtable) {
         if (dtable.getOutput().size() == 1) {
-            return setDisplayNameOnHasExpressionAndOutputClauseConsumer(updateStunnerTitle, oc);
+            return setDisplayNameOnHasExpressionAndOutputClauseConsumer(oc);
         }
-        return setDisplayNameConsumer(updateStunnerTitle);
+        return setValueConsumer(true);
     }
 
     @SuppressWarnings("unchecked")
-    private BiConsumer<HasName, Name> setDisplayNameOnHasExpressionAndOutputClauseConsumer(final boolean updateStunnerTitle,
-                                                                                           final OutputClause oc) {
-        return (hn, name) -> {
-            final CompositeCommand.Builder commandBuilder = newHasNameHasValueCommand(hn, name);
-            commandBuilder.addCommand(new SetHasNameCommand(wrapOutputClauseIntoHasName(oc),
-                                                            name,
-                                                            () -> {/*Nothing*/}));
-            if (updateStunnerTitle) {
-                getUpdateStunnerTitleCommand(name.getValue()).ifPresent(commandBuilder::addCommand);
-            }
+    private BiConsumer<HasName, Name> setDisplayNameOnHasExpressionAndOutputClauseConsumer(final OutputClause oc) {
+        return (hv, value) -> {
+            final CompositeCommand.Builder commandBuilder = newHasValueHasValueCommand(hv, value);
+            commandBuilder.addCommand(new SetHasValueCommand<>(wrapOutputClauseIntoHasName(oc),
+                                                               value,
+                                                               () -> {/*Nothing*/}));
+            getUpdateStunnerTitleCommand(value).ifPresent(commandBuilder::addCommand);
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           commandBuilder.build());
         };
@@ -408,6 +412,10 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                     uiModelMapper.fromDMNModel(rowIndex,
                                                columnIndex++);
                 }
+                for (int index = 0; index < e.getAnnotations().size(); index++) {
+                    uiModelMapper.fromDMNModel(rowIndex,
+                                               columnIndex++);
+                }
                 uiModelMapper.fromDMNModel(rowIndex,
                                            columnIndex);
             }
@@ -454,6 +462,11 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                                                                                                                 uiHeaderRowIndex,
                                                                                                                 uiHeaderColumnIndex) + 1)));
                     }
+                    break;
+                case ANNOTATION_CLAUSES:
+                    addRuleAnnotationClauseItems(items,
+                                                 uiHeaderColumnIndex,
+                                                 dtable.getAnnotations().size() <= 1);
             }
         });
 
@@ -484,6 +497,14 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                                          uiColumnIndex,
                                          isMultiColumn);
                     items.add(new ListSelectorDividerItem());
+                    break;
+
+                case ANNOTATION_CLAUSES:
+                    addRuleAnnotationClauseItems(items,
+                                                 uiColumnIndex,
+                                                 dtable.getAnnotations().size() <= 1);
+                    items.add(new ListSelectorDividerItem());
+                    break;
             }
 
             addDecisionRuleItems(dtable,
@@ -511,6 +532,22 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
                                                 () -> deleteInputClause(uiColumnIndex)));
     }
 
+    private void addRuleAnnotationClauseItems(final List<ListSelectorItem> items,
+                                              final int uiColumnIndex,
+                                              final boolean isSingleAnnotation) {
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.DecisionTableEditor_RuleAnnotationClauseHeader)));
+        addItems(items,
+                 new ListSelectorItemDefinition(translationService.format(DMNEditorConstants.DecisionTableEditor_InsertRuleAnnotationClauseLeft),
+                                                true,
+                                                () -> addRuleAnnotationClause(uiColumnIndex)),
+                 new ListSelectorItemDefinition(translationService.format(DMNEditorConstants.DecisionTableEditor_InsertRuleAnnotationClauseRight),
+                                                true,
+                                                () -> addRuleAnnotationClause(uiColumnIndex + 1)),
+                 new ListSelectorItemDefinition(translationService.format(DMNEditorConstants.DecisionTableEditor_DeleteRuleAnnotationClause),
+                                                !isSingleAnnotation,
+                                                () -> deleteRuleAnnotationClause(uiColumnIndex)));
+    }
+
     private void addOutputClauseItems(final List<ListSelectorItem> items,
                                       final DecisionTable dtable,
                                       final int uiColumnIndex,
@@ -616,6 +653,33 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
         });
     }
 
+    void addRuleAnnotationClause(final int index) {
+        getExpression().get().ifPresent(dtable -> {
+            final RuleAnnotationClause clause = new RuleAnnotationClause();
+
+            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                          new AddRuleAnnotationClauseCommand(dtable,
+                                                                             clause,
+                                                                             model,
+                                                                             () -> makeRuleAnnotationClauseColumn(index, clause),
+                                                                             index,
+                                                                             uiModelMapper,
+                                                                             () -> resize(BaseExpressionGrid.RESIZE_EXISTING),
+                                                                             () -> resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM)));
+        });
+    }
+
+    void deleteRuleAnnotationClause(final int index) {
+        getExpression().get().ifPresent(decisionTable ->
+                                                sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                                                              new DeleteRuleAnnotationClauseCommand(decisionTable,
+                                                                                                                    model,
+                                                                                                                    index,
+                                                                                                                    uiModelMapper,
+                                                                                                                    () -> resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM),
+                                                                                                                    () -> resize(BaseExpressionGrid.RESIZE_EXISTING))));
+    }
+
     void addOutputClause(final int index) {
         getExpression().get().ifPresent(dtable -> {
             final OutputClause clause = new OutputClause();
@@ -764,27 +828,50 @@ public class DecisionTableGrid extends BaseExpressionGrid<DecisionTable, Decisio
             final DecisionTableUIModelMapperHelper.DecisionTableSection section = DecisionTableUIModelMapperHelper.getSection(dtable, uiHeaderColumnIndex);
             switch (section) {
                 case INPUT_CLAUSES:
-                    final int icIndex = DecisionTableUIModelMapperHelper.getInputEntryIndex(dtable, uiHeaderColumnIndex);
-                    final InputClause inputClause = dtable.getInput().get(icIndex);
-                    fireDomainObjectSelectionEvent(inputClause);
+                    doAfterHeaderInputClauseSelectionChange(dtable, uiHeaderColumnIndex);
                     return;
                 case OUTPUT_CLAUSES:
-                    final List<GridColumn.HeaderMetaData> headerMetaData = model.getColumns().get(uiHeaderColumnIndex).getHeaderMetaData();
-                    if (headerMetaData.size() > 1) {
-                        if (uiHeaderRowIndex == 0) {
-                            final DMNModelInstrumentedBase base = hasExpression.asDMNModelInstrumentedBase();
-                            if (base instanceof DomainObject) {
-                                fireDomainObjectSelectionEvent((DomainObject) base);
-                                return;
-                            }
-                        }
-                    }
-                    final int ocIndex = DecisionTableUIModelMapperHelper.getOutputEntryIndex(dtable, uiHeaderColumnIndex);
-                    final OutputClause outputClause = dtable.getOutput().get(ocIndex);
-                    fireDomainObjectSelectionEvent(outputClause);
+                    doAfterHeaderOutputClauseSelectionChange(dtable, uiHeaderRowIndex, uiHeaderColumnIndex);
                     return;
             }
         }
         super.doAfterHeaderSelectionChange(uiHeaderRowIndex, uiHeaderColumnIndex);
     }
+
+    protected void doAfterHeaderInputClauseSelectionChange(final DecisionTable dtable,
+                                                           final int uiHeaderColumnIndex) {
+        final int icIndex = DecisionTableUIModelMapperHelper.getInputEntryIndex(dtable, uiHeaderColumnIndex);
+        final InputClause inputClause = dtable.getInput().get(icIndex);
+        fireDomainObjectSelectionEvent(inputClause);
+    }
+
+    protected void doAfterHeaderOutputClauseSelectionChange(final DecisionTable dtable,
+                                                            final int uiHeaderRowIndex,
+                                                            final int uiHeaderColumnIndex) {
+        final List<GridColumn.HeaderMetaData> headerMetaData = model.getColumns().get(uiHeaderColumnIndex).getHeaderMetaData();
+        if (uiHeaderRowIndex == 0 && headerMetaData.size() > 1) {
+            if (doFireDomainObjectSelectionEventForHasExpression()) {
+                return;
+            }
+        }
+        final int ocIndex = DecisionTableUIModelMapperHelper.getOutputEntryIndex(dtable, uiHeaderColumnIndex);
+        final OutputClause outputClause = dtable.getOutput().get(ocIndex);
+        fireDomainObjectSelectionEvent(outputClause);
+    }
+
+    protected boolean doFireDomainObjectSelectionEventForHasExpression() {
+        final DMNModelInstrumentedBase base = hasExpression.asDMNModelInstrumentedBase();
+        if (base instanceof DomainObject) {
+            fireDomainObjectSelectionEvent((DomainObject) base);
+            return true;
+        } else if (base instanceof ContextEntry) {
+            final ContextEntry contextEntry = (ContextEntry) base;
+            final InformationItem variable = contextEntry.getVariable();
+            if (Objects.nonNull(variable)) {
+                fireDomainObjectSelectionEvent(variable);
+                return true;
+            }
+        }
+        return false;
+    }
 }
