@@ -28,6 +28,7 @@ import org.kie.workbench.common.dmn.api.definition.HasVariable;
 import org.kie.workbench.common.dmn.api.definition.model.DRGElement;
 import org.kie.workbench.common.dmn.api.definition.model.IsInformationItem;
 import org.kie.workbench.common.dmn.api.property.dmn.Id;
+import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.api.property.dmn.QName;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
@@ -35,7 +36,6 @@ import org.kie.workbench.common.dmn.client.graph.DMNGraphUtils;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -56,7 +56,7 @@ public class DMNIncludedModelHandler implements DRGElementHandler {
     @Inject
     public DMNIncludedModelHandler(final DMNGraphUtils dmnGraphUtils,
                                    final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
-                                   final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                                   final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                    final DefinitionUtils definitionUtils) {
         this.dmnGraphUtils = dmnGraphUtils;
         this.canvasCommandFactory = canvasCommandFactory;
@@ -157,7 +157,7 @@ public class DMNIncludedModelHandler implements DRGElementHandler {
             final String nameId = definitionUtils.getNameIdentifier(definition.getDefinition());
 
             if (nameId != null) {
-                commandBuilder.addCommand(canvasCommandFactory.updatePropertyValue(node, nameId, newName));
+                commandBuilder.addCommand(canvasCommandFactory.updatePropertyValue(node, nameId, new Name(newName)));
             }
         }
 
