@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.dmn.client.editors.expressions.types.dtable;
 
+import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
 
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
@@ -26,6 +28,7 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.model.Context;
 import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
 import org.kie.workbench.common.dmn.api.definition.model.DMNDiagram;
+import org.kie.workbench.common.dmn.api.definition.model.Decision;
 import org.kie.workbench.common.dmn.api.definition.model.DecisionTable;
 import org.kie.workbench.common.dmn.api.definition.model.Definitions;
 import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
@@ -40,6 +43,8 @@ import org.kie.workbench.common.dmn.api.property.dmn.Id;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.api.property.dmn.QName;
 import org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType;
+import org.kie.workbench.common.dmn.client.editors.types.common.ItemDefinitionUtils;
+import org.kie.workbench.common.dmn.client.graph.DMNGraphUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
@@ -48,7 +53,14 @@ import org.kie.workbench.common.stunner.core.graph.impl.EdgeImpl;
 import org.kie.workbench.common.stunner.core.graph.impl.NodeImpl;
 import org.kie.workbench.common.stunner.core.util.UUID;
 
+import static java.util.Arrays.asList;
+import static java.util.Collections.emptyList;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.Assert.assertEquals;
+import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.NUMBER;
+import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.STRING;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTableEditorDefinitionTest {
@@ -59,9 +71,13 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
 
     private static final String INPUT_DATA_NAME_2 = "a-inputData2";
 
-    private static final QName INPUT_DATA_QNAME_1 = BuiltInType.STRING.asQName();
+    private static final QName INPUT_DATA_QNAME_1 = STRING.asQName();
 
-    private static final QName INPUT_DATA_QNAME_2 = BuiltInType.NUMBER.asQName();
+    private static final QName INPUT_DATA_QNAME_2 = NUMBER.asQName();
+
+    private static final String DECISION_NAME_1 = "b-decision1";
+
+    private static final QName DECISION_QNAME_1 = STRING.asQName();
 
     private static final QName OUTPUT_DATA_QNAME = BuiltInType.DATE.asQName();
 
@@ -71,6 +87,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
 
     private InputData inputData2;
 
+    private Decision decision1;
+
     @Before
     public void setup() {
         super.setup();
@@ -78,12 +96,37 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         this.diagram = new DMNDiagram();
         this.inputData1 = new InputData();
         this.inputData2 = new InputData();
+        this.decision1 = new Decision();
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testModelEnrichmentWhenTopLevelDecisionTableWithDecision() {
+        setupGraphWithDiagram();
+        setupGraphWithDecision();
+
+        final Optional<DecisionTable> oModel = definition.getModelClass();
+        definition.enrich(Optional.of(NODE_UUID), decision, oModel);
+
+        final DecisionTable model = oModel.get();
+        assertBasicEnrichment(model);
+
+        final List<InputClause> input = model.getInput();
+        assertThat(input.size()).isEqualTo(1);
+        assertThat(input.get(0).getInputExpression()).isInstanceOf(InputClauseLiteralExpression.class);
+        assertThat(input.get(0).getInputExpression().getText().getValue()).isEqualTo(DECISION_NAME_1);
+        assertThat(input.get(0).getInputExpression().getTypeRef()).isEqualTo(DECISION_QNAME_1);
+
+        assertStandardOutputClauseEnrichment(model);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testModelEnrichmentWhenTopLevelDecisionTableWithInputData() {
-        setupGraph();
+        setupGraphWithDiagram();
+        setupGraphWithInputData();
 
         final Optional<DecisionTable> oModel = definition.getModelClass();
         definition.enrich(Optional.of(NODE_UUID), decision, oModel);
@@ -101,14 +144,45 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(input.get(1).getInputExpression().getTypeRef()).isEqualTo(INPUT_DATA_QNAME_1);
 
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 2, 1);
-        assertParentHierarchyEnrichment(model, 2, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testModelEnrichmentWhenTopLevelDecisionTableWithDecisionAndInputData() {
+        setupGraphWithDiagram();
+        setupGraphWithDecision();
+        setupGraphWithInputData();
+
+        final Optional<DecisionTable> oModel = definition.getModelClass();
+        definition.enrich(Optional.of(NODE_UUID), decision, oModel);
+
+        final DecisionTable model = oModel.get();
+        assertBasicEnrichment(model);
+
+        final List<InputClause> input = model.getInput();
+        assertThat(input.size()).isEqualTo(3);
+        assertThat(input.get(0).getInputExpression()).isInstanceOf(InputClauseLiteralExpression.class);
+        assertThat(input.get(0).getInputExpression().getText().getValue()).isEqualTo(INPUT_DATA_NAME_2);
+        assertThat(input.get(0).getInputExpression().getTypeRef()).isEqualTo(INPUT_DATA_QNAME_2);
+        assertThat(input.get(1).getInputExpression()).isInstanceOf(InputClauseLiteralExpression.class);
+        assertThat(input.get(1).getInputExpression().getText().getValue()).isEqualTo(DECISION_NAME_1);
+        assertThat(input.get(1).getInputExpression().getTypeRef()).isEqualTo(DECISION_QNAME_1);
+        assertThat(input.get(2).getInputExpression()).isInstanceOf(InputClauseLiteralExpression.class);
+        assertThat(input.get(2).getInputExpression().getText().getValue()).isEqualTo(INPUT_DATA_NAME_1);
+        assertThat(input.get(2).getInputExpression().getTypeRef()).isEqualTo(INPUT_DATA_QNAME_1);
+
+        assertStandardOutputClauseEnrichment(model);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testModelEnrichmentWhenTopLevelDecisionTableWithInputDataAndSimpleCustomType() {
-        setupGraph();
+        setupGraphWithDiagram();
+        setupGraphWithInputData();
 
         final Definitions definitions = diagram.getDefinitions();
 
@@ -138,14 +212,15 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(input.get(1).getInputExpression().getTypeRef()).isEqualTo(simpleItemDefinitionTypeRef);
 
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 2, 1);
-        assertParentHierarchyEnrichment(model, 2, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testModelEnrichmentWhenTopLevelDecisionTableWithInputDataAndComplexCustomType() {
-        setupGraph();
+        setupGraphWithDiagram();
+        setupGraphWithInputData();
 
         final Definitions definitions = diagram.getDefinitions();
 
@@ -189,14 +264,15 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(input.get(2).getInputExpression().getTypeRef()).isEqualTo(complexItemDefinitionPart2TypeRef);
 
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 3, 1);
-        assertParentHierarchyEnrichment(model, 3, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testModelEnrichmentWhenTopLevelDecisionTableWithInputDataAndRecursiveCustomType() {
-        setupGraph();
+        setupGraphWithDiagram();
+        setupGraphWithInputData();
 
         final Definitions definitions = diagram.getDefinitions();
 
@@ -249,21 +325,22 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(input.get(3).getInputExpression().getTypeRef()).isEqualTo(parentCustomType);
 
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 4, 1);
-        assertParentHierarchyEnrichment(model, 4, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testModelEnrichmentWhenTopLevelDecisionTableWithMultipleHierarchyCustomTypes() {
-        setupGraph();
+        setupGraphWithDiagram();
+        setupGraphWithInputData();
 
         final Definitions definitions = diagram.getDefinitions();
 
         final String tSmurf = "tSmurf";
         final String tSmurfAddress = "tSmurfAddress";
         final QName dateBuiltInType = new QName(QName.NULL_NS_URI, BuiltInType.DATE.getName());
-        final QName stringBuiltInType = new QName(QName.NULL_NS_URI, BuiltInType.STRING.getName());
+        final QName stringBuiltInType = new QName(QName.NULL_NS_URI, STRING.getName());
 
         final ItemDefinition tSmurfAddressCustomDataType = new ItemDefinition();
         tSmurfAddressCustomDataType.setName(new Name(tSmurfAddress));
@@ -314,20 +391,57 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(input.get(3).getInputExpression().getTypeRef()).isEqualTo(dateBuiltInType);
 
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 4, 1);
-        assertParentHierarchyEnrichment(model, 4, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
+    }
+
+    private void setupGraphWithDiagram() {
+        final Node<Definition, Edge> diagramNode = new NodeImpl<>(UUID.uuid());
+        final Definition<DMNDiagram> diagramDefinition = new DefinitionImpl<>(diagram);
+        diagramNode.setContent(diagramDefinition);
+        graph.addNode(diagramNode);
     }
 
     @SuppressWarnings("unchecked")
-    private void setupGraph() {
-        final Node<Definition, Edge> diagramNode = new NodeImpl<>(UUID.uuid());
+    private void setupGraphWithDecision() {
+        Node<Definition, Edge> targetNode = graph.getNode(NODE_UUID);
+        if (Objects.isNull(targetNode)) {
+            targetNode = new NodeImpl<>(NODE_UUID);
+            graph.addNode(targetNode);
+        }
+
+        final Node<Definition, Edge> sourceNode1 = new NodeImpl<>(UUID.uuid());
+        decision1.getName().setValue(DECISION_NAME_1);
+        final QName decision1QName = new QName(QName.NULL_NS_URI, STRING.getName());
+        decision1.getVariable().setTypeRef(decision1QName);
+
+        final Definition<Decision> sourceNode1Definition = new DefinitionImpl<>(decision1);
+        sourceNode1.setContent(sourceNode1Definition);
+
+        final Edge edge1 = new EdgeImpl<>(UUID.uuid());
+        edge1.setTargetNode(targetNode);
+        edge1.setSourceNode(sourceNode1);
+
+        targetNode.getInEdges().add(edge1);
+        sourceNode1.getOutEdges().add(edge1);
+
+        graph.addNode(sourceNode1);
+    }
+
+    @SuppressWarnings("unchecked")
+    private void setupGraphWithInputData() {
+        Node<Definition, Edge> targetNode = graph.getNode(NODE_UUID);
+        if (Objects.isNull(targetNode)) {
+            targetNode = new NodeImpl<>(NODE_UUID);
+            graph.addNode(targetNode);
+        }
+
         final Node<Definition, Edge> sourceNode1 = new NodeImpl<>(UUID.uuid());
         final Node<Definition, Edge> sourceNode2 = new NodeImpl<>(UUID.uuid());
-        final Node<Definition, Edge> targetNode = new NodeImpl<>(NODE_UUID);
         inputData1.getName().setValue(INPUT_DATA_NAME_1);
         inputData2.getName().setValue(INPUT_DATA_NAME_2);
-        final QName inputData1QName = new QName(QName.NULL_NS_URI, BuiltInType.STRING.getName());
-        final QName inputData2QName = new QName(QName.NULL_NS_URI, BuiltInType.NUMBER.getName());
+        final QName inputData1QName = new QName(QName.NULL_NS_URI, STRING.getName());
+        final QName inputData2QName = new QName(QName.NULL_NS_URI, NUMBER.getName());
         inputData1.getVariable().setTypeRef(inputData1QName);
         inputData2.getVariable().setTypeRef(inputData2QName);
 
@@ -348,11 +462,6 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         sourceNode1.getOutEdges().add(edge1);
         sourceNode2.getOutEdges().add(edge2);
 
-        final Definition<DMNDiagram> diagramDefinition = new DefinitionImpl<>(diagram);
-        diagramNode.setContent(diagramDefinition);
-
-        graph.addNode(diagramNode);
-        graph.addNode(targetNode);
         graph.addNode(sourceNode1);
         graph.addNode(sourceNode2);
     }
@@ -370,8 +479,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertBasicEnrichment(model);
         assertStandardInputClauseEnrichment(model);
         assertStandardOutputClauseEnrichment(model);
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
@@ -398,8 +507,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(output.get(0).getName()).isEqualTo(name);
         assertThat(output.get(0).getTypeRef()).isEqualTo(OUTPUT_DATA_QNAME);
 
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
@@ -429,8 +538,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(output.get(0).getName()).isEqualTo(name);
         assertThat(output.get(0).getTypeRef()).isEqualTo(OUTPUT_DATA_QNAME);
 
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
@@ -465,8 +574,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(output.get(0).getName()).isEqualTo(name);
         assertThat(output.get(0).getTypeRef()).isEqualTo(OUTPUT_DATA_QNAME);
 
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
@@ -486,8 +595,8 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(output.get(0).getName()).isEqualTo("output-1");
         assertThat(output.get(0).getTypeRef()).isEqualTo(OUTPUT_DATA_QNAME);
 
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
     }
 
     @Test
@@ -505,7 +614,71 @@ public class DecisionTableEditorDefinitionEnricherTest extends BaseDecisionTable
         assertThat(output.get(0).getName()).isEqualTo("output-1");
         assertThat(output.get(0).getTypeRef()).isEqualTo(BuiltInType.UNDEFINED.asQName());
 
-        assertStandardDecisionRuleEnrichment(model, 1, 1);
-        assertParentHierarchyEnrichment(model, 1, 1);
+        assertStandardDecisionRuleEnrichment(model);
+        assertParentHierarchyEnrichment(model);
+    }
+
+    @Test
+    public void testAddInputClauseRequirement() {
+
+        final ItemDefinition tPerson = mock(ItemDefinition.class);
+        final ItemDefinition name = mock(ItemDefinition.class);
+        final ItemDefinition age = mock(ItemDefinition.class);
+        final List<DecisionTableEditorDefinitionEnricher.InputClauseRequirement> inputClauseRequirements = new ArrayList<>();
+        final String inputData = "InputData";
+        final DecisionTableEditorDefinitionEnricher enricher = new DecisionTableEditorDefinitionEnricher(null, null, itemDefinitionUtils);
+
+        /* === ItemDefinition ===
+         * - tPerson (Structure)
+         *   - name  (String)
+         *   - age   (Number)
+         * ======================
+         */
+
+        when(name.getName()).thenReturn(new Name("name"));
+        when(name.getTypeRef()).thenReturn(STRING.asQName());
+        when(name.getItemComponent()).thenReturn(emptyList());
+
+        when(age.getName()).thenReturn(new Name("age"));
+        when(age.getTypeRef()).thenReturn(NUMBER.asQName());
+        when(age.getItemComponent()).thenReturn(emptyList());
+
+        when(tPerson.getName()).thenReturn(new Name("tPerson"));
+        when(tPerson.getTypeRef()).thenReturn(null);
+        when(tPerson.getItemComponent()).thenReturn(asList(name, age));
+
+        enricher.addInputClauseRequirement(tPerson, inputClauseRequirements, inputData);
+
+        assertEquals(2, inputClauseRequirements.size());
+
+        final DecisionTableEditorDefinitionEnricher.InputClauseRequirement inputClause1 = inputClauseRequirements.get(0);
+        final DecisionTableEditorDefinitionEnricher.InputClauseRequirement inputClause2 = inputClauseRequirements.get(1);
+
+        assertEquals("InputData.name", inputClause1.text);
+        assertEquals(STRING.getName(), inputClause1.typeRef.getLocalPart());
+
+        assertEquals("InputData.age", inputClause2.text);
+        assertEquals(NUMBER.getName(), inputClause2.typeRef.getLocalPart());
+    }
+
+    @Test
+    public void testAddInputClauseRequirementWhenDataTypeIsStructureAndDontHaveFields() {
+
+        final ItemDefinition tPerson = mock(ItemDefinition.class);
+        final String inputData = "InputData";
+        final List<DecisionTableEditorDefinitionEnricher.InputClauseRequirement> inputClauseRequirements = new ArrayList<>();
+        final ItemDefinitionUtils itemDefinitionUtils = new ItemDefinitionUtils(mock(DMNGraphUtils.class));
+        final DecisionTableEditorDefinitionEnricher enricher = new DecisionTableEditorDefinitionEnricher(null, null, itemDefinitionUtils);
+
+        when(tPerson.getName()).thenReturn(new Name("tPerson"));
+        when(tPerson.getTypeRef()).thenReturn(null);
+        when(tPerson.getItemComponent()).thenReturn(emptyList());
+
+        enricher.addInputClauseRequirement(tPerson, inputClauseRequirements, inputData);
+
+        assertEquals(1, inputClauseRequirements.size());
+
+        assertEquals("InputData", inputClauseRequirements.get(0).text);
+        assertEquals("tPerson", inputClauseRequirements.get(0).typeRef.getLocalPart());
     }
 }
