@@ -129,12 +129,6 @@ public class QNameFieldRendererTest {
         verify(formGroup).render(eq(typePicker), eq(definition));
     }
 
-    @Test
-    public void testGetSupportedCode() {
-        assertEquals(QNameFieldDefinition.FIELD_TYPE.getTypeName(),
-                     renderer.getSupportedCode());
-    }
-
     @Test
     public void testSetReadOnly() {
         renderer.setReadOnly(false);
