@@ -32,14 +32,17 @@ import org.kie.workbench.common.dmn.client.editors.types.DataTypesPage;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
 import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
+import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
 import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDiagramDock;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
+import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
 import org.kie.workbench.common.stunner.core.client.ManagedInstanceStub;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasFileExport;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.components.layout.LayoutHelper;
 import org.kie.workbench.common.stunner.core.client.components.layout.OpenDiagramLayoutExecutor;
@@ -87,9 +90,11 @@ import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -227,6 +232,12 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Mock
     protected ClientRuntimeError clientRuntimeError;
 
+    @Mock
+    protected MonacoFEELInitializer feelInitializer;
+
+    @Mock
+    protected CanvasFileExport canvasFileExport;
+
     @Captor
     protected ArgumentCaptor<KogitoDiagramResourceImpl> kogitoDiagramResourceArgumentCaptor;
 
@@ -369,7 +380,7 @@ public abstract class AbstractDMNDiagramEditorTest {
 
         editor.onClose();
 
-        verify(dmnEditorMenuSessionItems).destroy();
+        verify(dmnEditorMenuSessionItems, times(2)).destroy();
         verify(editorPresenter).destroy();
 
         verify(decisionNavigatorDock).destroy();
@@ -423,9 +434,10 @@ public abstract class AbstractDMNDiagramEditorTest {
 
     @Test
     public void testSetContentSuccess() {
-        editor.setContent(CONTENT);
+        final String path = "path";
+        editor.setContent(path, CONTENT);
 
-        verify(clientDiagramService).transform(eq(CONTENT), serviceCallbackArgumentCaptor.capture());
+        verify(clientDiagramService).transform(eq(path), eq(CONTENT), serviceCallbackArgumentCaptor.capture());
 
         final ServiceCallback<Diagram> serviceCallback = serviceCallbackArgumentCaptor.getValue();
         assertThat(serviceCallback).isNotNull();
@@ -436,14 +448,16 @@ public abstract class AbstractDMNDiagramEditorTest {
 
     @Test
     public void testSetContentFailure() {
-        editor.setContent(CONTENT);
+        final String path = "path";
+        editor.setContent(path, CONTENT);
 
-        verify(clientDiagramService).transform(eq(CONTENT), serviceCallbackArgumentCaptor.capture());
+        verify(clientDiagramService).transform(eq(path), eq(CONTENT), serviceCallbackArgumentCaptor.capture());
 
         final ServiceCallback<Diagram> serviceCallback = serviceCallbackArgumentCaptor.getValue();
         assertThat(serviceCallback).isNotNull();
         serviceCallback.onError(clientRuntimeError);
 
+        verify(feelInitializer, never()).initializeFEELEditor();
         verify(diagramClientErrorHandler).handleError(eq(clientRuntimeError), any());
     }
 
@@ -467,13 +481,26 @@ public abstract class AbstractDMNDiagramEditorTest {
         when(editorPresenter.getInstance()).thenReturn(session);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
 
-        editor.open(diagram);
+        editor.open(diagram, mock(Viewer.Callback.class));
 
         assertOnDiagramLoad();
     }
 
     protected void assertOnDiagramLoad() {
         verify(decisionNavigatorDock).setupCanvasHandler(canvasHandler);
+        verify(layoutHelper).applyLayout(eq(diagram), eq(layoutExecutor));
+        verify(feelInitializer).initializeFEELEditor();
         verify(dataTypesPage).reload();
     }
+
+    @Test
+    public void testSuperOnCloseDMNOnSetContent() {
+        //First setContent call context
+        editor.setContent("", "");
+        verify(dmnEditorMenuSessionItems, times(1)).destroy();
+
+        //Second setContent call context
+        editor.setContent("", "");
+        verify(dmnEditorMenuSessionItems, times(2)).destroy();
+    }
 }
