@@ -24,6 +24,7 @@ import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTyp
 import org.kie.workbench.common.dmn.showcase.client.navigator.DMNVFSService;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditorTest;
+import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasFileExport;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
 import org.kie.workbench.common.stunner.kogito.client.PromiseMock;
 import org.mockito.ArgumentCaptor;
@@ -39,6 +40,7 @@ import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.util.URIUtil;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
@@ -82,7 +84,9 @@ public class DMNDiagramEditorTest extends AbstractDMNDiagramEditorTest {
     private DMNVFSService vfsService;
 
     @Mock
-    private Promises promises;
+    private CanvasFileExport canvasFileExport;
+
+    private Promises promises = new SyncPromises();
 
     @Captor
     private ArgumentCaptor<Command> commandArgumentCaptor;
@@ -142,7 +146,9 @@ public class DMNDiagramEditorTest extends AbstractDMNDiagramEditorTest {
                                     dataTypesPage,
                                     clientDiagramService,
                                     vfsService,
-                                    promises) {
+                                    promises,
+                                    feelInitializer,
+                                    canvasFileExport) {
 
             @Override
             protected PlaceRequest getPlaceRequest() {
@@ -167,7 +173,7 @@ public class DMNDiagramEditorTest extends AbstractDMNDiagramEditorTest {
     public void testOnStartup() {
         super.testOnStartup();
 
-        verify(editor).setContent(eq(""));
+        verify(editor).setContent(eq(""), eq(""));
     }
 
     @Test
