@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,20 +23,15 @@ public interface FormValidator<MODEL> {
 
     public static final String NESTED_PROPERTY_SEPARATOR = "_";
 
-    /**
-     * Sets the {@link FormFieldProvider} for the given rendered form
-     */
-    void setFormFieldProvider( FormFieldProvider formFieldProvider );
-
     /**
      * Validates the given form model
      * @return True or false depending on the validations
      */
-    boolean validate( MODEL model );
+    boolean validate(Form form, MODEL model);
 
     /**
      * Validates a specific field value.
      * @return True or false depending on the validation
      */
-    boolean validate( String fieldName, MODEL model );
+    boolean validate(FormField formField, MODEL model);
 }
