@@ -22,6 +22,7 @@ import java.util.Optional;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
@@ -35,6 +36,7 @@ import org.kie.workbench.common.forms.model.FormDefinition;
 import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.mockito.verification.VerificationMode;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
@@ -457,7 +459,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     @Test
     public void testMakeMenuBar() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         loadContent();
 
@@ -466,8 +468,9 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         verify(menuBuilderMock).addRename(any(Command.class));
         verify(menuBuilderMock).addDelete(any(Command.class));
         verify(menuBuilderMock).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(menuBuilderMock).addNewTopLevelMenu(downloadMenuItem);
 
-        assertNotNull(presenter.getMenus());
+        presenter.getMenus(Assert::assertNotNull);
         verify(menuBuilderMock,
                atLeastOnce()).build();
     }
@@ -475,7 +478,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         loadContent();
 
@@ -492,7 +495,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
                                   any(AssetUpdateValidator.class));
         verify(menuBuilderMock).addNewTopLevelMenu(alertsButtonMenuItem);
 
-        assertNotNull(presenter.getMenus());
+        presenter.getMenus(Assert::assertNotNull);
         verify(menuBuilderMock,
                atLeastOnce()).build();
     }
@@ -678,4 +681,28 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         verify(presenterSpy).getRenameErrorCallback(any(RenamePopUpPresenter.View.class));
         verify(presenterSpy).getRenameSuccessCallback(any(RenamePopUpPresenter.View.class));
     }
+
+    @Test
+    public void testOnLockStatusChange() {
+        loadContent();
+        FormEditorPresenter presenterSpy = spy(presenter);
+        UpdatedLockStatusEvent updatedLockStatusEvent = new UpdatedLockStatusEvent(versionRecordManager.getCurrentPath(),
+                                                               true,false);
+        presenterSpy.onLockStatusChange(updatedLockStatusEvent);
+        verify(layoutEditorMock).lock();
+        updatedLockStatusEvent = new UpdatedLockStatusEvent(versionRecordManager.getCurrentPath(),
+                                                               false, false);
+        presenterSpy.onLockStatusChange(updatedLockStatusEvent);
+        verify(layoutEditorMock).unlock();
+    }
+
+    @Test
+    public void testOnLockStatusChangeOnLockByCurrentUser(){
+        loadContent();
+        FormEditorPresenter presenterSpy = spy(presenter);
+        UpdatedLockStatusEvent updatedLockStatusEvent = new UpdatedLockStatusEvent(versionRecordManager.getCurrentPath(),
+                                                                                   true, true);
+        presenterSpy.onLockStatusChange(updatedLockStatusEvent);
+        verify(layoutEditorMock).unlock();
+    }
 }
