@@ -31,13 +31,15 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.screens.explorer.model.FolderItem;
 import org.kie.workbench.common.screens.explorer.model.FolderItemOperation;
+import org.kie.workbench.common.screens.explorer.model.FolderItemType;
 import org.kie.workbench.common.screens.explorer.service.ActiveOptions;
 import org.kie.workbench.common.screens.explorer.service.Option;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.backend.server.UserServicesImpl;
 import org.uberfire.backend.server.VFSLockServiceImpl;
+import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.commons.async.DescriptiveThreadFactory;
@@ -54,58 +56,40 @@ import static org.mockito.Mockito.*;
 public class ExplorerServiceHelperTest {
 
     private SimpleFileSystemProvider fileSystemProvider;
-
     @Mock
-    private KieProjectService projectService;
-
+    private KieModuleService moduleService;
     @Mock
     private FolderListingResolver folderListingResolver;
-
     @Mock
     private IOService ioService;
-
     @Mock
     private IOService ioServiceConfig;
-
     @Mock
     private OtherMetaView otherMetaView;
-
     @Mock
     private VFSLockServiceImpl lockService;
-
     @Mock
     private MetadataService metadataService;
-
     @Mock
     private UserServicesImpl userServices;
-
     @Mock
     private DeleteService deleteService;
-
     @Mock
     private RenameService renameService;
-
     @Mock
     private CopyService copyService;
-
     @Mock
     private Package pkg;
-
     @Mock
     private Package childPkg;
-
     @Mock
     private Path srcPath;
-
     @Mock
     private Path srcTestPath;
-
     @Mock
     private Path srcResourcesPath;
-
     @Mock
     private Path testResourcesPath;
-
     private org.uberfire.java.nio.file.Path path;
     private ExplorerServiceHelper helper;
 
@@ -149,7 +133,7 @@ public class ExplorerServiceHelperTest {
 
         ExecutorService executorService = Executors.newCachedThreadPool(new DescriptiveThreadFactory());
 
-        helper = spy(new ExplorerServiceHelper(projectService,
+        helper = spy(new ExplorerServiceHelper(moduleService,
                                                folderListingResolver,
                                                ioService,
                                                ioServiceConfig,
@@ -292,7 +276,7 @@ public class ExplorerServiceHelperTest {
         doReturn(false).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(false).when(helper).hasAssets(childPkg);
 
         assertFalse(helper.hasAssets(pkg));
@@ -306,7 +290,7 @@ public class ExplorerServiceHelperTest {
         doReturn(false).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(false).when(helper).hasAssets(childPkg);
 
         assertTrue(helper.hasAssets(pkg));
@@ -320,7 +304,7 @@ public class ExplorerServiceHelperTest {
         doReturn(false).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(false).when(helper).hasAssets(childPkg);
 
         assertTrue(helper.hasAssets(pkg));
@@ -334,7 +318,7 @@ public class ExplorerServiceHelperTest {
         doReturn(false).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(false).when(helper).hasAssets(childPkg);
 
         assertTrue(helper.hasAssets(pkg));
@@ -348,7 +332,7 @@ public class ExplorerServiceHelperTest {
         doReturn(true).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(false).when(helper).hasAssets(childPkg);
 
         assertTrue(helper.hasAssets(pkg));
@@ -362,12 +346,58 @@ public class ExplorerServiceHelperTest {
         doReturn(false).when(helper).hasAssets(testResourcesPath);
         doReturn(new HashSet<Package>() {{
             add(childPkg);
-        }}).when(projectService).resolvePackages(pkg);
+        }}).when(moduleService).resolvePackages(pkg);
         doReturn(true).when(helper).hasAssets(childPkg);
 
         assertTrue(helper.hasAssets(pkg));
     }
 
+    @Test
+    public void getPathSegmentsRootTest() {
+        doAnswer(invocationOnMock -> {
+            final Path p = Paths.convert((org.uberfire.java.nio.file.Path) invocationOnMock.getArguments()[0]);
+            return new FolderItem(p,
+                                  p.getFileName(),
+                                  FolderItemType.FOLDER);
+        }).when(helper).toFolderItem(any(org.uberfire.java.nio.file.Path.class));
+
+        Path path = PathFactory.newPath("/",
+                                        "default://master@myproject/");
+
+        final List<FolderItem> pathSegments = helper.getPathSegments(path);
+
+        assertEquals(0,
+                     pathSegments.size());
+    }
+
+    @Test
+    public void getPathSegmentsTest() {
+        doAnswer(invocationOnMock -> {
+            final Path p = Paths.convert((org.uberfire.java.nio.file.Path) invocationOnMock.getArguments()[0]);
+            return new FolderItem(p,
+                                  p.getFileName(),
+                                  FolderItemType.FOLDER);
+        }).when(helper).toFolderItem(any(org.uberfire.java.nio.file.Path.class));
+
+        Path path = PathFactory.newPath("myproject",
+                                        "default://master@myproject/src/main/java/org/myproject");
+
+        final List<FolderItem> pathSegments = helper.getPathSegments(path);
+
+        assertEquals(5,
+                     pathSegments.size());
+        assertEquals("/",
+                     pathSegments.get(0).getFileName());
+        assertEquals("src",
+                     pathSegments.get(1).getFileName());
+        assertEquals("main",
+                     pathSegments.get(2).getFileName());
+        assertEquals("java",
+                     pathSegments.get(3).getFileName());
+        assertEquals("org",
+                     pathSegments.get(4).getFileName());
+    }
+
     private void givenThatOperationHasRestrictions(FolderItemOperation operation) {
         mockOperationRestrictions(operation,
                                   true);
