@@ -21,8 +21,6 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Optional;
-import java.util.function.Consumer;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.stream.Collectors;
@@ -34,21 +32,14 @@ import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import com.ait.lienzo.client.core.shape.wires.ILocationAcceptor;
-import com.ait.lienzo.client.core.shape.wires.SelectionManager;
 import com.ait.lienzo.client.core.shape.wires.WiresContainer;
 import com.ait.lienzo.client.core.shape.wires.WiresManager;
-import com.ait.lienzo.client.core.shape.wires.WiresShape;
-import com.ait.lienzo.client.core.shape.wires.handlers.impl.ShapeControlUtils;
-import com.ait.lienzo.client.core.types.BoundingBox;
-import com.ait.lienzo.client.core.types.Point2DArray;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
-import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresUtils;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.AbstractCanvasHandlerRegistrationControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.CanvasControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.drag.LocationControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.LocationControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher;
 import org.kie.workbench.common.stunner.core.client.canvas.event.ShapeLocationsChangedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
@@ -60,27 +51,26 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
-import org.kie.workbench.common.stunner.core.client.shape.view.HasDragBounds;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasEventHandlers;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
+import org.kie.workbench.common.stunner.core.client.shape.view.event.DragEvent;
+import org.kie.workbench.common.stunner.core.client.shape.view.event.DragHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseEnterEvent;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseEnterHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseExitEvent;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseExitHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewEventType;
+import org.kie.workbench.common.stunner.core.client.util.ShapeUtils;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
-import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
-import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
-import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
@@ -101,19 +91,26 @@ public class LocationControlImpl
     private final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
     private final Event<ShapeLocationsChangedEvent> shapeLocationsChangedEvent;
     private CommandManagerProvider<AbstractCanvasHandler> commandManagerProvider;
-    private double[] boundsConstraint;
     private final Collection<String> selectedIDs = new LinkedList<>();
+    private final Event<CanvasSelectionEvent> selectionEvent;
 
     protected LocationControlImpl() {
         this(null,
+             null,
              null);
     }
 
     @Inject
     public LocationControlImpl(final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
-                               final Event<ShapeLocationsChangedEvent> shapeLocationsChangedEvent) {
+                               final Event<ShapeLocationsChangedEvent> shapeLocationsChangedEvent,
+                               final Event<CanvasSelectionEvent> selectionEvent) {
         this.canvasCommandFactory = canvasCommandFactory;
         this.shapeLocationsChangedEvent = shapeLocationsChangedEvent;
+        this.selectionEvent = selectionEvent;
+    }
+
+    public Collection<String> getSelectedIDs() {
+        return selectedIDs;
     }
 
     @Override
@@ -131,8 +128,7 @@ public class LocationControlImpl
         handleArrowKeys(keys);
     }
 
-    private void handleArrowKeys(final KeyboardEvent.Key... keys) {
-
+    public void handleArrowKeys(final KeyboardEvent.Key... keys) {
         final int selectedIDsCount = selectedIDs.size();
 
         if (selectedIDsCount == 0) {
@@ -197,17 +193,17 @@ public class LocationControlImpl
     @SuppressWarnings("unchecked")
     public void register(final Element element) {
         if (null != element.asNode() && checkNotRegistered(element)) {
-            final Canvas<?> canvas = canvasHandler.getCanvas();
+            final AbstractCanvas<?> canvas = canvasHandler.getAbstractCanvas();
             final Shape<?> shape = canvas.getShape(element.getUUID());
+            final ShapeView shapeView = shape.getShapeView();
 
-            // Drag & constraints.
-            shape.getShapeView().setDragEnabled(true);
-            if (shape.getShapeView() instanceof HasDragBounds) {
-                ensureDragConstraints((HasDragBounds<?>) shape.getShapeView());
-            }
+            // Enable drag & ensure location constraints are set, if any.
+            shapeView.setDragEnabled(true);
+            ensureDragConstraints(canvas, shapeView);
 
+            // Register handlers.
             if (shape.getShapeView() instanceof HasEventHandlers) {
-                final HasEventHandlers hasEventHandlers = (HasEventHandlers) shape.getShapeView();
+                final HasEventHandlers hasEventHandlers = (HasEventHandlers) shapeView;
 
                 // Change mouse cursor, if shape supports it.
                 if (supportsMouseEnter(hasEventHandlers) &&
@@ -225,13 +221,33 @@ public class LocationControlImpl
                     final MouseExitHandler outHandler = new MouseExitHandler() {
                         @Override
                         public void handle(MouseExitEvent event) {
-                            canvasHandler.getAbstractCanvas().getView().setCursor(AbstractCanvas.Cursors.AUTO);
+                            canvasHandler.getAbstractCanvas().getView().setCursor(AbstractCanvas.Cursors.DEFAULT);
                         }
                     };
                     hasEventHandlers.addHandler(ViewEventType.MOUSE_EXIT,
                                                 outHandler);
                     registerHandler(shape.getUUID(),
                                     outHandler);
+
+                    //Adding DragHandler on the shape to check whether the moving shape is not selected, th
+                    final DragHandler dragHandler = new DragHandler() {
+                        @Override
+                        public void start(DragEvent event) {
+                            // Instead of firing the event on Drag start, now will be fired at the end, hence improving performance
+                        }
+
+                        @Override
+                        public void end(DragEvent event) {
+                            selectionEvent.fire(new CanvasSelectionEvent(canvasHandler, shape.getUUID()));
+                        }
+
+                        @Override
+                        public void handle(DragEvent event) {
+                        }
+                    };
+
+                    hasEventHandlers.addHandler(ViewEventType.DRAG, dragHandler);
+                    registerHandler(shape.getUUID(), dragHandler);
                 }
             }
         }
@@ -253,20 +269,6 @@ public class LocationControlImpl
         for (int i = 0; i < elements.length; i++) {
             final Element element = elements[i];
             builder.addCommand(createMoveCommand(element, locations[i]));
-
-            //check connectors
-            ShapeView shapeView = canvasHandler.getCanvas().getShape(element.getUUID()).getShapeView();
-            if (shapeView instanceof WiresShape) {
-                ShapeControlUtils.getChildConnectorWithinShape((WiresShape) shapeView).values()
-                        .stream()
-                        .forEach(wiresConnector -> {
-                            Optional.ofNullable(canvasHandler.getGraphIndex().getEdge(WiresUtils.getShapeUUID(wiresConnector.getGroup())))
-                                    .ifPresent(edge -> {
-                                        final Point2DArray controlPoints = wiresConnector.getControlPoints();
-                                        builder.addCommands(moveControlPointsCommands(edge, controlPoints));
-                                    });
-                        });
-            }
         }
 
         final Command<AbstractCanvasHandler, CanvasViolation> command = builder.build();
@@ -284,18 +286,8 @@ public class LocationControlImpl
         return result;
     }
 
-    private List<Command<AbstractCanvasHandler, CanvasViolation>> moveControlPointsCommands(Edge edge, Point2DArray controlPoints) {
-        return ((ViewConnector) edge.getContent()).getControlPoints()
-                .stream()
-                .map(cp -> {
-                    com.ait.lienzo.client.core.types.Point2D lienzoCP = controlPoints.get(cp.getIndex());
-                    return canvasCommandFactory.updateControlPointPosition(edge, cp, new Point2D(lienzoCP.getX(), lienzoCP.getY()));
-                }).collect(Collectors.toList());
-    }
-
     @Override
     protected void doClear() {
-        ifSelectionManager(s -> s.getControl().setBoundsConstraint(null));
         selectedIDs.clear();
         super.doClear();
     }
@@ -305,7 +297,6 @@ public class LocationControlImpl
         clear();
         getWiresManager().setLocationAcceptor(ILocationAcceptor.ALL);
         commandManagerProvider = null;
-        boundsConstraint = null;
         super.doDestroy();
     }
 
@@ -327,33 +318,6 @@ public class LocationControlImpl
         }
     }
 
-    @SuppressWarnings("unchecked")
-    private void ensureDragConstraints(final HasDragBounds<?> shapeView) {
-        if (null == boundsConstraint) {
-            boundsConstraint = getLocationBounds();
-            // Selection multiple bounding constraints.
-            ifSelectionManager(s -> s.getControl().setBoundsConstraint(new BoundingBox(boundsConstraint[0],
-                                                                                       boundsConstraint[1],
-                                                                                       boundsConstraint[2],
-                                                                                       boundsConstraint[3])));
-        }
-        // Shape drag bounds.
-        shapeView.setDragBounds(boundsConstraint[0],
-                                boundsConstraint[1],
-                                boundsConstraint[2],
-                                boundsConstraint[3]);
-    }
-
-    @SuppressWarnings("unchecked")
-    private double[] getLocationBounds() {
-        final Graph<DefinitionSet, ? extends Node> graph = canvasHandler.getDiagram().getGraph();
-        final Bounds bounds = graph.getContent().getBounds();
-        return new double[]{bounds.getUpperLeft().getX(),
-                bounds.getUpperLeft().getY(),
-                bounds.getLowerRight().getX(),
-                bounds.getLowerRight().getY()};
-    }
-
     @SuppressWarnings("unchecked")
     private CanvasCommand<AbstractCanvasHandler> createMoveCommand(final Element element,
                                                                    final Point2D location) {
@@ -413,14 +377,16 @@ public class LocationControlImpl
         }
     };
 
+    @SuppressWarnings("unchecked")
+    private static void ensureDragConstraints(final AbstractCanvas<?> canvas,
+                                              final ShapeView shapeView) {
+        final Bounds bounds = canvas.getView().getPanel().getLocationConstraints();
+        ShapeUtils.enforceLocationConstraints(shapeView,
+                                              bounds);
+    }
+
     private WiresManager getWiresManager() {
         final WiresCanvas canvas = (WiresCanvas) canvasHandler.getCanvas();
         return canvas.getWiresManager();
     }
-
-    private void ifSelectionManager(Consumer<SelectionManager> selectionManagerConsumer) {
-        if (null != getWiresManager().getSelectionManager()) {
-            selectionManagerConsumer.accept(getWiresManager().getSelectionManager());
-        }
-    }
 }
