@@ -43,6 +43,7 @@ import org.mockito.Mock;
 import static org.junit.Assert.assertNotNull;
 import static org.kie.workbench.common.stunner.client.widgets.resources.i18n.StunnerWidgetsConstants.SessionPresenterView_Error;
 import static org.kie.workbench.common.stunner.client.widgets.resources.i18n.StunnerWidgetsConstants.SessionPresenterView_Info;
+import static org.kie.workbench.common.stunner.client.widgets.resources.i18n.StunnerWidgetsConstants.SessionPresenterView_Notifications;
 import static org.kie.workbench.common.stunner.client.widgets.resources.i18n.StunnerWidgetsConstants.SessionPresenterView_Warning;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.doAnswer;
@@ -58,6 +59,7 @@ import static org.mockito.Mockito.when;
 @WithClassesToStub(NotifySettings.class)
 public class SessionPresenterViewTest extends AbstractCanvasHandlerViewerTest {
 
+    public static final String DETAILS_MESSAGE = "details message";
     @Mock
     private ContextMenuEvent contextMenuEvent;
 
@@ -146,6 +148,8 @@ public class SessionPresenterViewTest extends AbstractCanvasHandlerViewerTest {
         doReturn(sessionContainerElement).when(sessionContainer).getElement();
         doReturn(sessionContainerElementStyle).when(sessionContainerElement).getStyle();
 
+        when(translationService.getTranslation(SessionPresenterView_Notifications)).thenReturn(DETAILS_MESSAGE);
+
         tested.init();
     }
 
@@ -240,19 +244,21 @@ public class SessionPresenterViewTest extends AbstractCanvasHandlerViewerTest {
 
     @Test
     public void testShowWarning() {
-
         final SessionPresenterView view = spy(new SessionPresenterView());
-        final String message = "Hello<br />World";
         final String warning = "Warning";
 
         when(translationService.getTranslation(SessionPresenterView_Warning)).thenReturn(warning);
         when(view.getTranslationService()).thenReturn(translationService);
         when(view.getSettings()).thenReturn(settings);
 
-        view.showWarning(message);
+        //call 3 times
+        view.showWarning();
+        view.showWarning();
+        view.showWarning();
 
+        //called just once
         verify(settings).setType("warning kie-session-notification");
-        verify(view).showNotification(warning, message, IconType.EXCLAMATION_TRIANGLE);
+        verify(view).showNotification(warning, DETAILS_MESSAGE, IconType.EXCLAMATION_TRIANGLE);
     }
 
     @Test
