@@ -18,17 +18,23 @@ package org.kie.workbench.common.stunner.core.client.canvas;
 
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
+import java.util.function.Supplier;
 
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.listener.CanvasDomainObjectListener;
 import org.kie.workbench.common.stunner.core.client.canvas.listener.CanvasElementListener;
 import org.kie.workbench.common.stunner.core.client.canvas.listener.HasCanvasListeners;
+import org.kie.workbench.common.stunner.core.client.canvas.listener.HasDomainObjectListeners;
 import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasLayoutUtils;
+import org.kie.workbench.common.stunner.core.client.command.QueueGraphExecutionContext;
 import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
@@ -49,10 +55,13 @@ import org.kie.workbench.common.stunner.core.util.UUID;
  */
 public abstract class AbstractCanvasHandler<D extends Diagram, C extends AbstractCanvas>
         implements CanvasHandler<D, C>,
-                   HasCanvasListeners<CanvasElementListener> {
+                   HasCanvasListeners<CanvasElementListener>,
+                   HasDomainObjectListeners<CanvasDomainObjectListener> {
 
     private final String uuid;
     private final List<CanvasElementListener> listeners = new LinkedList<>();
+    private final List<CanvasDomainObjectListener> domainObjectListeners = new LinkedList<>();
+    private Supplier<GraphCommandExecutionContext> commandExecutionContextSupplier;
 
     public AbstractCanvasHandler() {
         this.uuid = UUID.uuid();
@@ -91,7 +100,9 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
      * If the implementation is not going to perform model updates, the graph execution context can be
      * either <code>null</code> or an empty context type.
      */
-    public abstract GraphCommandExecutionContext getGraphExecutionContext();
+    public GraphCommandExecutionContext getGraphExecutionContext() {
+        return commandExecutionContextSupplier.get();
+    }
 
     /**
      * This method sets the given <code>child</code> instance as children for the given
@@ -216,6 +227,11 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
                          final boolean fireEvents) {
         assert factory != null && candidate != null;
         final Shape shape = factory.newShape(candidate.getContent().getDefinition());
+
+        if (shape == null) {
+            return;
+        }
+
         // Set the same identifier as the graph element's one.
         if (null == shape.getUUID()) {
             shape.setUUID(candidate.getUUID());
@@ -242,6 +258,10 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
     public void deregister(final Element element,
                            final boolean fireEvents) {
         final Shape shape = getCanvas().getShape(element.getUUID());
+        if (Objects.isNull(shape)) {
+            //already not exists on canvas
+            return;
+        }
         deregister(shape,
                    element,
                    fireEvents);
@@ -308,6 +328,10 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         }
     }
 
+    public void setGraphExecutionContext(final Supplier<GraphCommandExecutionContext> commandExecutionContextSupplier) {
+        this.commandExecutionContextSupplier = commandExecutionContextSupplier;
+    }
+
     /**
      * Adds a listener instance in order to be notified about graph element structure updates.
      * @param instance The listener instance.
@@ -337,13 +361,22 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         return this;
     }
 
-    /**
-     * Notifies an element removed to the listeners.
-     */
-    public void notifyCanvasElementRemoved(final Element candidate) {
-        for (final CanvasElementListener instance : listeners) {
-            instance.deregister(candidate);
-        }
+    @Override
+    public HasDomainObjectListeners<CanvasDomainObjectListener> addDomainObjectListener(final CanvasDomainObjectListener instance) {
+        domainObjectListeners.add(instance);
+        return this;
+    }
+
+    @Override
+    public HasDomainObjectListeners<CanvasDomainObjectListener> removeDomainObjectListener(final CanvasDomainObjectListener instance) {
+        domainObjectListeners.remove(instance);
+        return this;
+    }
+
+    @Override
+    public HasDomainObjectListeners<CanvasDomainObjectListener> clearDomainObjectListeners() {
+        domainObjectListeners.clear();
+        return this;
     }
 
     /**
@@ -355,12 +388,48 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         }
     }
 
+    /**
+     * Notifies an element removed to the listeners.
+     */
+    public void notifyCanvasElementRemoved(final Element candidate) {
+        for (final CanvasElementListener instance : listeners) {
+            instance.deregister(candidate);
+        }
+    }
+
+    private GraphCommandExecutionContext graphContext = null;
+
+    /**
+     * Sets the Graphic Context to be used for multiple operations
+     * @param graphContext Graph context to be set
+     */
+    public void setStaticContext(GraphCommandExecutionContext graphContext) {
+        this.graphContext = graphContext;
+    }
+
     /**
      * Notifies an element updated to the listeners.
      */
     public void notifyCanvasElementUpdated(final Element candidate) {
+
+        if (graphContext != null) {
+            if (graphContext instanceof QueueGraphExecutionContext) {
+                ((QueueGraphExecutionContext) graphContext).addElement(candidate);
+            } else {
+                for (final CanvasElementListener instance : listeners) {
+                    instance.update(candidate);
+                }
+            }
+        }
+    }
+
+    /**
+     * Does Batch update
+     * @param queue Queue to be sent to be updated
+     */
+    public void doBatchUpdate(final List<Element> queue) {
         for (final CanvasElementListener instance : listeners) {
-            instance.update(candidate);
+            instance.updateBatch(queue);
         }
     }
 
@@ -373,9 +442,46 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         }
     }
 
+    /**
+     * Notifies {@link CanvasDomainObjectListener}s that a {@link DomainObject} has been added.
+     */
+    public void notifyCanvasDomainObjectAdded(final DomainObject domainObject) {
+        for (final CanvasDomainObjectListener instance : domainObjectListeners) {
+            instance.register(domainObject);
+        }
+    }
+
+    /**
+     * Notifies {@link CanvasDomainObjectListener}s that a {@link DomainObject} has been removed.
+     */
+    public void notifyCanvasDomainObjectRemoved(final DomainObject domainObject) {
+        for (final CanvasDomainObjectListener instance : domainObjectListeners) {
+            instance.deregister(domainObject);
+        }
+    }
+
+    /**
+     * Notifies {@link CanvasDomainObjectListener}s that a {@link DomainObject} has been updated.
+     */
+    public void notifyCanvasDomainObjectUpdated(final DomainObject domainObject) {
+        for (final CanvasDomainObjectListener instance : domainObjectListeners) {
+            instance.update(domainObject);
+        }
+    }
+
+    /**
+     * Notifies {@link CanvasDomainObjectListener}s that the {@link Canvas} has been cleared.
+     */
+    public void notifyCanvasDomainObjectClear() {
+        for (final CanvasDomainObjectListener instance : domainObjectListeners) {
+            instance.clear();
+        }
+    }
+
     public void clearCanvas() {
         if (null != getCanvas()) {
             notifyCanvasClear();
+            notifyCanvasDomainObjectClear();
             getCanvas().clear();
         }
     }
@@ -402,6 +508,8 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         getCanvas().destroy();
         doDestroy();
         listeners.clear();
+        domainObjectListeners.clear();
+        commandExecutionContextSupplier = null;
     }
 
     /**
@@ -440,6 +548,6 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
 
     @Override
     public String toString() {
-        return this.getClass().getName() + " [" + getUuid() + "]";
+        return this.getClass().getSimpleName() + " [" + getUuid() + "]";
     }
 }
