@@ -16,24 +16,35 @@
 
 package org.kie.workbench.common.stunner.core.client.session.command.impl;
 
+import java.lang.annotation.Annotation;
+
+import javax.enterprise.event.Event;
+
+import org.appformer.client.stateControl.registry.Registry;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
+import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.DeleteNodeCommand;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.LocalClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
+import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
 import org.kie.workbench.common.stunner.core.graph.Element;
-import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
+import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -45,11 +56,20 @@ public class CutSelectionSessionCommandTest extends BaseSessionCommandKeyboardSe
 
     private CutSelectionSessionCommand cutSelectionSessionCommand;
 
+    @Mock
+    private SessionManager sessionManager;
+
     @Mock
     private CopySelectionSessionCommand copySelectionSessionCommand;
 
     @Mock
-    private DeleteSelectionSessionCommand deleteSelectionSessionCommand;
+    private Event<CanvasClearSelectionEvent> canvasClearSelectionEventEvent;
+
+    @Mock
+    private DefinitionUtils definitionUtils;
+
+    @Mock
+    private ManagedInstance<CanvasCommandFactory<AbstractCanvasHandler>> canvasCommandFactoryInstance;
 
     @Mock
     private EventSourceMock<CutSelectionSessionCommandExecutedEvent> commandExecutedEvent;
@@ -61,40 +81,54 @@ public class CutSelectionSessionCommandTest extends BaseSessionCommandKeyboardSe
     private ClientSessionCommand.Callback mainCallback;
 
     @Mock
-    private CommandRegistry commandRegistry;
+    private Registry commandRegistry;
 
     @Mock
     private DeleteNodeCommand deleteNodeCommand;
 
-    @Mock
-    private SessionCommandFactory sessionCommandFactory;
-
     private ClipboardControl<Element, AbstractCanvas, ClientSession> clipboardControl;
 
+    private final String DEFINITION_SET_ID = "mockDefinitionSetId";
+
+    @Mock
+    private Annotation qualifier;
+
     @Before
+    @SuppressWarnings("unchecked")
     public void setUp() throws Exception {
         clipboardControl = spy(new LocalClipboardControl());
-        when(sessionCommandFactory.newCopySelectionCommand()).thenReturn(copySelectionSessionCommand);
-        when(sessionCommandFactory.newDeleteSelectedElementsCommand()).thenReturn(deleteSelectionSessionCommand);
-        when(sessionCommandManager.getRegistry()).thenReturn(commandRegistry);
+        when(session.getCommandRegistry()).thenReturn(commandRegistry);
         when(commandRegistry.peek()).thenReturn(deleteNodeCommand);
         when(session.getClipboardControl()).thenReturn(clipboardControl);
-        commandExecutedEventCaptor = ArgumentCaptor.forClass(CutSelectionSessionCommandExecutedEvent.class);
+        when(sessionManager.getCurrentSession()).thenReturn(session);
+
+        when(metadata.getDefinitionSetId()).thenReturn(DEFINITION_SET_ID);
+        when(definitionUtils.getQualifier(eq(DEFINITION_SET_ID))).thenReturn(qualifier);
+        when(canvasCommandFactoryInstance.select(eq(qualifier))).thenReturn(canvasCommandFactoryInstance);
+        when(canvasCommandFactoryInstance.isUnsatisfied()).thenReturn(false);
+        when(canvasCommandFactoryInstance.get()).thenReturn(canvasCommandFactory);
+
         super.setup();
         this.cutSelectionSessionCommand = getCommand();
+
+        commandExecutedEventCaptor = ArgumentCaptor.forClass(CutSelectionSessionCommandExecutedEvent.class);
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testExecute() {
+
         cutSelectionSessionCommand.bind(session);
+        CopySelectionSessionCommand.getInstance(sessionManager).bind(session);
+        cutSelectionSessionCommand.setCopySelectionSessionCommand(copySelectionSessionCommand);
         cutSelectionSessionCommand.execute(mainCallback);
+
         ArgumentCaptor<ClientSessionCommand.Callback> callbackArgumentCaptor = ArgumentCaptor.forClass(ClientSessionCommand.Callback.class);
         verify(copySelectionSessionCommand).execute(callbackArgumentCaptor.capture());
 
         //success
         callbackArgumentCaptor.getValue().onSuccess();
-        verify(deleteSelectionSessionCommand, times(1)).execute(mainCallback);
-        verify(sessionCommandManager.getRegistry(), atLeastOnce()).peek();
+        verify(session.getCommandRegistry(), atLeastOnce()).peek();
         verify(clipboardControl, atLeastOnce()).setRollbackCommand(deleteNodeCommand);
         verify(commandExecutedEvent, times(1)).fire(commandExecutedEventCaptor.capture());
         assertEquals(session, commandExecutedEventCaptor.getValue().getClientSession());
@@ -108,7 +142,7 @@ public class CutSelectionSessionCommandTest extends BaseSessionCommandKeyboardSe
 
     @Override
     protected CutSelectionSessionCommand getCommand() {
-        return new CutSelectionSessionCommand(sessionCommandFactory, sessionCommandManager, commandExecutedEvent);
+        return new CutSelectionSessionCommand(commandExecutedEvent, sessionManager);
     }
 
     @Override
