@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.forms.client.widgets;
 
+import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
 
@@ -24,6 +25,7 @@ import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
+import com.google.gwt.user.client.Timer;
 import org.kie.workbench.common.forms.dynamic.service.shared.RenderMode;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
@@ -38,7 +40,6 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
-import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
@@ -56,12 +57,15 @@ import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull
 @Dependent
 public class FormsCanvasSessionHandler {
 
+    /**
+     * An ORDERED array of feature providers supported.
+     */
+    private static final FormFeaturesSessionProvider[] FEATURE_SESSION_PROVIDERS = new FormFeaturesSessionProvider[]{new FormFeaturesFullSessionProvider(), new FormFeaturesReadOnlySessionProvider()};
     private final DefinitionManager definitionManager;
     private final CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
     private final FormsCanvasListener canvasListener;
     private final FormsDomainObjectCanvasListener domainObjectCanvasListener;
     private final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
-
     private ClientSession session;
     private FormFeaturesSessionProvider featuresSessionProvider;
     private FormRenderer renderer;
@@ -69,7 +73,7 @@ public class FormsCanvasSessionHandler {
     @Inject
     public FormsCanvasSessionHandler(final DefinitionManager definitionManager,
                                      final CanvasCommandFactory<AbstractCanvasHandler> commandFactory,
-                                     final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager) {
+                                     final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager) {
         this.definitionManager = definitionManager;
         this.commandFactory = commandFactory;
         this.canvasListener = getFormsCanvasListener();
@@ -164,7 +168,7 @@ public class FormsCanvasSessionHandler {
     void onRefreshFormPropertiesEvent(@Observes RefreshFormPropertiesEvent event) {
         checkNotNull("event", event);
 
-        if (checkSession(event.getSession())) {
+        if (checkSession(event.getSession())) { // Possible Improvement
             if (event.hasUuid()) {
                 final String uuid = event.getUuid();
                 final Element<? extends Definition<?>> element = CanvasLayoutUtils.getElement(getCanvasHandler(), uuid);
@@ -178,15 +182,29 @@ public class FormsCanvasSessionHandler {
     void onCanvasSelectionEvent(@Observes CanvasSelectionEvent event) {
         checkNotNull("event",
                      event);
+
         if (checkCanvasHandler(event.getCanvasHandler())) {
             if (event.getIdentifiers().size() == 1) {
                 final String uuid = event.getIdentifiers().iterator().next();
                 final Element<? extends Definition<?>> element = CanvasLayoutUtils.getElement(getCanvasHandler(), uuid);
+                scheduleRender(() -> render(element));
+            } else {
+                // Select root canvas
+                final Element<? extends Definition<?>> element = CanvasLayoutUtils.getElement(getCanvasHandler(), this.getDiagram().getMetadata().getCanvasRootUUID());
                 render(element);
             }
         }
     }
 
+    protected void scheduleRender(final com.google.gwt.user.client.Command command) {
+        new Timer() {
+            @Override
+            public void run() {
+                command.execute();
+            }
+        }.schedule(100);
+    }
+
     void onDomainObjectSelectionEvent(@Observes DomainObjectSelectionEvent event) {
         checkNotNull("event",
                      event);
@@ -267,6 +285,121 @@ public class FormsCanvasSessionHandler {
         return checkCanvasHandler(s.getCanvasHandler());
     }
 
+    private FormFeaturesSessionProvider getFeaturesSessionProvider(final ClientSession session) {
+        for (final FormFeaturesSessionProvider featureSessionProvider : FEATURE_SESSION_PROVIDERS) {
+            if (featureSessionProvider.supports(session)) {
+                return featureSessionProvider;
+            }
+        }
+        return null;
+    }
+
+    private interface FormsListener {
+
+        void startProcessing();
+
+        void endProcessing();
+    }
+
+    /**
+     * Provides form features to the {@link FormsCanvasSessionHandler}
+     */
+    public interface FormRenderer {
+
+        /**
+         * Renders the form properties panel for the given {@link Element}
+         * @param graphUuid the current {@link Graph} UUID
+         * @param element the {@link Element} to render properties form
+         * @param callback a {@link Command} to execute after a property value change
+         */
+        void render(String graphUuid, Element element, Command callback);
+
+        /**
+         * Renders the form properties panel for the given {@link Object}
+         * @param graphUuid the current {@link Graph} UUID
+         * @param domainObject the {@link DomainObject} to render properties form
+         * @param callback a {@link Command} to execute after a property value change
+         */
+        void render(String graphUuid, DomainObject domainObject, Command callback);
+
+        /**
+         * Clears the properties form for the given {@link Element}
+         * @param graphUuid the current {@link Graph} UUID
+         * @param element the {@link Element} to clear its properties form
+         */
+        void clear(String graphUuid, Element element);
+
+        /**
+         * Clears all properties forms for the current {@link Graph}
+         * @param graphUuid the current {@link Graph} UUID
+         */
+        void clearAll(String graphUuid);
+
+        /**
+         * Resets Cache
+         */
+        void resetCache();
+
+        /**
+         * Checks if Positions are the same for the last element rendered and if Elements are the same
+         * @param element Element to be checked
+         * @return True if Elements are the same and their positions or False if they are not
+         */
+        boolean areLastPositionsSameForElement(final Element element);
+    }
+
+    /**
+     * This type provides required features that are specific for concrete client
+     * session types.
+     */
+    private interface FormFeaturesSessionProvider<S extends ClientSession> {
+
+        /**
+         * Returns <code>true</code> is the session type is supported.
+         */
+        boolean supports(ClientSession type);
+
+        /**
+         * Returns the session's selection control instance, if not available, it
+         * returns <code>null</code>.
+         */
+        SelectionControl getSelectionControl(S session);
+    }
+
+    private static class FormFeaturesReadOnlySessionProvider implements FormFeaturesSessionProvider<ViewerSession> {
+
+        @Override
+        public boolean supports(final ClientSession type) {
+            return type instanceof ViewerSession;
+        }
+
+        @Override
+        public SelectionControl getSelectionControl(final ViewerSession session) {
+            return cast(session).getSelectionControl();
+        }
+
+        private ViewerSession cast(final ClientSession session) {
+            return (ViewerSession) session;
+        }
+    }
+
+    private static class FormFeaturesFullSessionProvider implements FormFeaturesSessionProvider<EditorSession> {
+
+        @Override
+        public boolean supports(final ClientSession type) {
+            return type instanceof EditorSession;
+        }
+
+        @Override
+        public SelectionControl getSelectionControl(final EditorSession session) {
+            return cast(session).getSelectionControl();
+        }
+
+        private EditorSession cast(final ClientSession session) {
+            return (EditorSession) session;
+        }
+    }
+
     /**
      * A listener that refresh the forms once an element has been updated,
      * but it skips the refreshing when updates come from this forms widget instance.
@@ -306,8 +439,21 @@ public class FormsCanvasSessionHandler {
 
         @Override
         public void update(final Element item) {
+
+            if (!Objects.isNull(renderer) && renderer.areLastPositionsSameForElement(item)) {
+                renderer.resetCache();
+            }
+
             if (!areFormsProcessing) {
-                render(item);
+                scheduleRender(() -> render(item));
+            }
+        }
+
+        @Override
+        public void updateBatch(final List<Element> queue) {
+            if (!queue.isEmpty()) {
+                // No point in updating lots of elements, just last one or if single the only one
+                update(queue.get(queue.size() - 1));
             }
         }
 
@@ -378,112 +524,4 @@ public class FormsCanvasSessionHandler {
             }
         }
     }
-
-    private interface FormsListener {
-
-        void startProcessing();
-
-        void endProcessing();
-    }
-
-    private FormFeaturesSessionProvider getFeaturesSessionProvider(final ClientSession session) {
-        for (final FormFeaturesSessionProvider featureSessionProvider : FEATURE_SESSION_PROVIDERS) {
-            if (featureSessionProvider.supports(session)) {
-                return featureSessionProvider;
-            }
-        }
-        return null;
-    }
-
-    /**
-     * Provides form features to the {@link FormsCanvasSessionHandler}
-     */
-    public interface FormRenderer {
-
-        /**
-         * Renders the form properties panel for the given {@link Element}
-         * @param graphUuid the current {@link Graph} UUID
-         * @param element the {@link Element} to render properties form
-         * @param callback a {@link Command} to execute after a property value change
-         */
-        void render(String graphUuid, Element element, Command callback);
-
-        /**
-         * Renders the form properties panel for the given {@link Object}
-         * @param graphUuid the current {@link Graph} UUID
-         * @param domainObject the {@link DomainObject} to render properties form
-         * @param callback a {@link Command} to execute after a property value change
-         */
-        void render(String graphUuid, DomainObject domainObject, Command callback);
-
-        /**
-         * Clears the properties form for the given {@link Element}
-         * @param graphUuid the current {@link Graph} UUID
-         * @param element the {@link Element} to clear its properties form
-         */
-        void clear(String graphUuid, Element element);
-
-        /**
-         * Clears all properties forms for the current {@link Graph}
-         * @param graphUuid the current {@link Graph} UUID
-         */
-        void clearAll(String graphUuid);
-    }
-
-    /**
-     * An ORDERED array of feature providers supported.
-     */
-    private static final FormFeaturesSessionProvider[] FEATURE_SESSION_PROVIDERS = new FormFeaturesSessionProvider[]{new FormFeaturesFullSessionProvider(), new FormFeaturesReadOnlySessionProvider()};
-
-    /**
-     * This type provides required features that are specific for concrete client
-     * session types.
-     */
-    private interface FormFeaturesSessionProvider<S extends ClientSession> {
-
-        /**
-         * Returns <code>true</code> is the session type is supported.
-         */
-        boolean supports(ClientSession type);
-
-        /**
-         * Returns the session's selection control instance, if not available, it
-         * returns <code>null</code>.
-         */
-        SelectionControl getSelectionControl(S session);
-    }
-
-    private static class FormFeaturesReadOnlySessionProvider implements FormFeaturesSessionProvider<ViewerSession> {
-
-        @Override
-        public boolean supports(final ClientSession type) {
-            return type instanceof ViewerSession;
-        }
-
-        @Override
-        public SelectionControl getSelectionControl(final ViewerSession session) {
-            return cast(session).getSelectionControl();
-        }
-
-        private ViewerSession cast(final ClientSession session) {
-            return (ViewerSession) session;
-        }
-    }
-
-    private static class FormFeaturesFullSessionProvider implements FormFeaturesSessionProvider<EditorSession> {
-
-        @Override
-        public boolean supports(final ClientSession type) {
-            return type instanceof EditorSession;
-        }
-
-        @Override
-        public SelectionControl getSelectionControl(final EditorSession session) {
-            return cast(session).getSelectionControl();
-        }
-
-        private EditorSession cast(final ClientSession session) {
-            return (EditorSession) session;
-        }
-    }
 }
