@@ -13,47 +13,55 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.kie.workbench.common.stunner.bpmn.definition;
 
-import java.util.HashSet;
 import java.util.Set;
 
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.soup.commons.util.Sets;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseManagementSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.DiagramSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.RectangleDimensionsSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = BPMNDiagramImpl.BPMNDiagramBuilder.class)
+@Definition(graphFactory = NodeFactory.class)
 @CanContain(roles = {"all"})
 @FormDefinition(
         startElement = "diagramSet",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
-public class BPMNDiagramImpl implements BPMNDiagram {
+public class BPMNDiagramImpl implements BPMNDiagram<DiagramSet, ProcessData, AdvancedData> {
 
     @Category
     public static final transient String category = BPMNCategories.CONTAINERS;
+    public static final String DIAGRAM_SET = "diagramSet";
+    public static final String PROCESS_DATA = "processData";
+    public static final String ADVANCED_DATA = "advancedData";
+    public static final String CASE_MANAGEMENT_SET = "caseManagementSet";
 
     @PropertySet
     @FormField
@@ -62,11 +70,24 @@ public class BPMNDiagramImpl implements BPMNDiagram {
 
     @PropertySet
     @FormField(
-            afterElement = "diagramSet"
+            afterElement = DIAGRAM_SET
     )
     @Valid
     protected ProcessData processData;
 
+    @PropertySet
+    @FormField(
+            afterElement = PROCESS_DATA
+    )
+    @Valid
+    protected AdvancedData advancedData;
+
+    @PropertySet
+    @FormField(
+            afterElement = ADVANCED_DATA
+    )
+    protected CaseManagementSet caseManagementSet;
+
     @PropertySet
     private BackgroundSet backgroundSet;
 
@@ -77,41 +98,39 @@ public class BPMNDiagramImpl implements BPMNDiagram {
     protected RectangleDimensionsSet dimensionsSet;
 
     @Labels
-    private final Set<String> labels = new HashSet<String>() {{
-        add("canContainArtifacts");
-        add("diagram");
-    }};
+    private final Set<String> labels = new Sets.Builder<String>()
+            .add("canContainArtifacts")
+            .add("diagram")
+            .build();
 
-    @NonPortable
-    public static class BPMNDiagramBuilder implements Builder<BPMNDiagramImpl> {
-
-        public static final Double WIDTH = 950d;
-        public static final Double HEIGHT = 950d;
-
-        @Override
-        public BPMNDiagramImpl build() {
-            return new BPMNDiagramImpl(new DiagramSet(),
-                                       new ProcessData(),
-                                       new BackgroundSet(),
-                                       new FontSet(),
-                                       new RectangleDimensionsSet(WIDTH,
-                                                                  HEIGHT));
-        }
-    }
+    public static final Double WIDTH = 950d;
+    public static final Double HEIGHT = 950d;
 
     public BPMNDiagramImpl() {
+        this(new DiagramSet(),
+             new ProcessData(),
+             new CaseManagementSet(),
+             new BackgroundSet(),
+             new FontSet(),
+             new RectangleDimensionsSet(WIDTH,
+                                        HEIGHT),
+             new AdvancedData());
     }
 
-    public BPMNDiagramImpl(final @MapsTo("diagramSet") DiagramSet diagramSet,
-                           final @MapsTo("processData") ProcessData processData,
+    public BPMNDiagramImpl(final @MapsTo(DIAGRAM_SET) DiagramSet diagramSet,
+                           final @MapsTo(PROCESS_DATA) ProcessData processData,
+                           final @MapsTo(CASE_MANAGEMENT_SET) CaseManagementSet caseManagementSet,
                            final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
                            final @MapsTo("fontSet") FontSet fontSet,
-                           final @MapsTo("dimensionsSet") RectangleDimensionsSet dimensionsSet) {
+                           final @MapsTo("dimensionsSet") RectangleDimensionsSet dimensionsSet,
+                           final @MapsTo(ADVANCED_DATA) AdvancedData advancedData) {
         this.diagramSet = diagramSet;
         this.processData = processData;
+        this.caseManagementSet = caseManagementSet;
         this.backgroundSet = backgroundSet;
         this.fontSet = fontSet;
         this.dimensionsSet = dimensionsSet;
+        this.advancedData = advancedData;
     }
 
     public String getCategory() {
@@ -122,6 +141,7 @@ public class BPMNDiagramImpl implements BPMNDiagram {
         return labels;
     }
 
+    @Override
     public DiagramSet getDiagramSet() {
         return diagramSet;
     }
@@ -134,30 +154,47 @@ public class BPMNDiagramImpl implements BPMNDiagram {
         this.dimensionsSet = dimensionsSet;
     }
 
+    @Override
     public ProcessData getProcessData() {
         return processData;
     }
 
+    @Override
+    public CaseManagementSet getCaseManagementSet() {
+        return caseManagementSet;
+    }
+
+    @Override
+    public void setCaseManagementSet(final CaseManagementSet caseManagementSet) {
+        this.caseManagementSet = caseManagementSet;
+    }
+
+    @Override
     public BackgroundSet getBackgroundSet() {
         return backgroundSet;
     }
 
+    @Override
     public FontSet getFontSet() {
         return fontSet;
     }
 
+    @Override
     public void setDiagramSet(final DiagramSet diagramSet) {
         this.diagramSet = diagramSet;
     }
 
+    @Override
     public void setProcessData(final ProcessData processData) {
         this.processData = processData;
     }
 
+    @Override
     public void setBackgroundSet(final BackgroundSet backgroundSet) {
         this.backgroundSet = backgroundSet;
     }
 
+    @Override
     public void setFontSet(final FontSet fontSet) {
         this.fontSet = fontSet;
     }
@@ -167,13 +204,25 @@ public class BPMNDiagramImpl implements BPMNDiagram {
         return null;
     }
 
+    @Override
+    public AdvancedData getAdvancedData() {
+        return advancedData;
+    }
+
+    @Override
+    public void setAdvancedData(AdvancedData advancedData) {
+        this.advancedData = advancedData;
+    }
+
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(diagramSet.hashCode(),
                                          processData.hashCode(),
+                                         caseManagementSet.hashCode(),
                                          backgroundSet.hashCode(),
                                          fontSet.hashCode(),
-                                         dimensionsSet.hashCode());
+                                         dimensionsSet.hashCode(),
+                                         advancedData.hashCode());
     }
 
     @Override
@@ -182,9 +231,11 @@ public class BPMNDiagramImpl implements BPMNDiagram {
             BPMNDiagramImpl other = (BPMNDiagramImpl) o;
             return diagramSet.equals(other.diagramSet) &&
                     processData.equals(other.processData) &&
+                    caseManagementSet.equals(other.caseManagementSet) &&
                     backgroundSet.equals(other.backgroundSet) &&
                     fontSet.equals(other.fontSet) &&
-                    dimensionsSet.equals(other.dimensionsSet);
+                    dimensionsSet.equals(other.dimensionsSet) &&
+                    advancedData.equals(other.advancedData);
         }
         return false;
     }
